#ifndef MP4V2_PROJECT_H
#define MP4V2_PROJECT_H

/*****************************************************************************/

#define MP4V2_PROJECT_name            "MP4v2"
#define MP4V2_PROJECT_name_lower      "mp4v2"
#define MP4V2_PROJECT_name_upper      "MP4V2"
#define MP4V2_PROJECT_name_formal     "MP4v2 1.9.1"
#define MP4V2_PROJECT_url_website     "http://code.google.com/p/mp4v2"
#define MP4V2_PROJECT_url_downloads   "http://code.google.com/p/mp4v2/downloads/list"
#define MP4V2_PROJECT_url_discussion  "http://groups.google.com/group/mp4v2"
#define MP4V2_PROJECT_irc             "irc://irc.freenode.net/mp4v2"
#define MP4V2_PROJECT_bugreport       "<eddyg@myreflection.org>"
#define MP4V2_PROJECT_version         "1.9.1"
#define MP4V2_PROJECT_version_hex     0x00010901
#define MP4V2_PROJECT_version_major   1
#define MP4V2_PROJECT_version_minor   9
#define MP4V2_PROJECT_version_point   1
#define MP4V2_PROJECT_repo_url        "https://mp4v2.googlecode.com/svn/releases/1.9.1"
#define MP4V2_PROJECT_repo_root       "https://mp4v2.googlecode.com/svn"
#define MP4V2_PROJECT_repo_uuid       "6e6572fa-98a6-11dd-ad9f-f77439c74b79"
#define MP4V2_PROJECT_repo_rev        368
#define MP4V2_PROJECT_repo_date       "2009-07-14 11:25:03 +1200 (Tue, 14 Jul 2009)"
#define MP4V2_PROJECT_repo_type       "stable"
#define MP4V2_PROJECT_build           "Mon Oct  4 05:55:00 UTC 2021"

/*****************************************************************************/

#endif /* MP4V2_PROJECT_H */
